nvector.objects.Pvector
=======================

.. currentmodule:: nvector.objects

.. autoclass:: Pvector

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Pvector.__init__
      ~Pvector.delta_to
      ~Pvector.to_ecef_vector
      ~Pvector.to_geo_point
      ~Pvector.to_nvector
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~Pvector.azimuth
      ~Pvector.azimuth_deg
      ~Pvector.elevation
      ~Pvector.elevation_deg
      ~Pvector.length
   
   